@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 19:00:00                  #
+# Updated Date: 2025.09.14 20:00:00                  #
 # ================================================== #
 
 from pygpt_net.core.events import (
@@ -31,16 +31,19 @@ class EventsDebug:
 
     def update(self):
         """Update debug window."""
-        self.window.core.debug.begin(self.id)
-        self.window.core.debug.add(self.id, 'App Events:', str(self.extract_events(AppEvent)))
-        self.window.core.debug.add(self.id, 'Control Events:', str(self.extract_events(ControlEvent)))
-        self.window.core.debug.add(self.id, 'Kernel Events:', str(self.extract_events(KernelEvent)))
-        self.window.core.debug.add(self.id, 'Render Events:', str(self.extract_events(RenderEvent)))
-        self.window.core.debug.add(self.id, 'Plugin Events:', str(self.extract_events(Event)))
-        self.window.core.debug.add(self.id, '----', '')
-        self.window.core.debug.add(self.id, 'Voice Cmds (all):', str(self.window.core.access.voice.commands))
-        self.window.core.debug.add(self.id, 'Voice Cmds (allowed):', str(self.window.core.access.voice.get_commands()))
-        self.window.core.debug.end(self.id)
+        debug = self.window.core.debug
+        access_voice = self.window.core.access.voice
+
+        debug.begin(self.id)
+        debug.add(self.id, 'App Events:', str(self.extract_events(AppEvent)))
+        debug.add(self.id, 'Control Events:', str(self.extract_events(ControlEvent)))
+        debug.add(self.id, 'Kernel Events:', str(self.extract_events(KernelEvent)))
+        debug.add(self.id, 'Render Events:', str(self.extract_events(RenderEvent)))
+        debug.add(self.id, 'Plugin Events:', str(self.extract_events(Event)))
+        debug.add(self.id, '----', '')
+        debug.add(self.id, 'Voice Cmds (all):', str(access_voice.commands))
+        debug.add(self.id, 'Voice Cmds (allowed):', str(access_voice.get_commands()))
+        debug.end(self.id)
 
     def extract_events(self, events: BaseEvent) -> dict:
         """
