@@ -6,16 +6,22 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.06.30 02:00:00                  #
+# Updated Date: 2025.09.04 00:00:00                  #
 # ================================================== #
 
 import json
-from typing import Optional, Dict, Any
+from dataclasses import dataclass
+from typing import Optional, Dict, Any, ClassVar
 
 from pygpt_net.item.ctx import CtxItem
 from .base import BaseEvent
 
+
+@dataclass(slots=True)
 class Event(BaseEvent):
+    """Generic event with context serialization"""
+    # static id for event family
+    id: ClassVar[str] = "Event"
 
     # Events
     AI_NAME = "ai.name"
@@ -23,13 +29,14 @@ class Event(BaseEvent):
     AUDIO_INPUT_RECORD_START = "audio.input.record.start"  # start audio input recording
     AUDIO_INPUT_RECORD_STOP = "audio.input.record.stop"  # stop audio input recording
     AUDIO_INPUT_RECORD_TOGGLE = "audio.input.record.toggle"  # toggle audio input recording
-    AUDIO_INPUT_TRANSCRIBE = "audio.input.transcribe"  # transcribe audio file
     AUDIO_INPUT_STOP = "audio.input.stop"
     AUDIO_INPUT_TOGGLE = "audio.input.toggle"
+    AUDIO_INPUT_TRANSCRIBE = "audio.input.transcribe"  # transcribe audio file
     AUDIO_OUTPUT_STOP = "audio.output.stop"
     AUDIO_OUTPUT_TOGGLE = "audio.output.toggle"
     AUDIO_PLAYBACK = "audio.playback"
     AUDIO_READ_TEXT = "audio.read_text"
+    BRIDGE_BEFORE = "bridge.before"
     CMD_EXECUTE = "cmd.execute"
     CMD_INLINE = "cmd.inline"
     CMD_SYNTAX = "cmd.syntax"
@@ -42,14 +49,16 @@ class Event(BaseEvent):
     DISABLE = "disable"
     ENABLE = "enable"
     FORCE_STOP = "force.stop"
+    INPUT_ACCEPT = "input.accept"
     INPUT_BEFORE = "input.before"
+    INPUT_BEGIN = "input.begin"
     MODE_BEFORE = "mode.before"
     MODE_SELECT = "mode.select"
     MODEL_BEFORE = "model.before"
     MODEL_SELECT = "model.select"
     MODELS_CHANGED = "models.changed"
-    PLUGIN_SETTINGS_CHANGED = "plugin.settings.changed"
     PLUGIN_OPTION_GET = "plugin.option.get"
+    PLUGIN_SETTINGS_CHANGED = "plugin.settings.changed"
     POST_PROMPT = "post.prompt"
     POST_PROMPT_ASYNC = "post.prompt.async"
     POST_PROMPT_END = "post.prompt.end"
@@ -60,63 +69,4 @@ class Event(BaseEvent):
     UI_ATTACHMENTS = "ui.attachments"
     UI_VISION = "ui.vision"
     USER_NAME = "user.name"
-    USER_SEND = "user.send"
-
-    def __init__(
-            self,
-            name: Optional[str] = None,
-            data: Optional[dict] = None,
-            ctx: Optional[CtxItem] = None
-    ):
-        """
-        Event object class
-
-        :param name: event name
-        :param data: event data
-        :param ctx: context instance
-        """
-        super(Event, self).__init__(name, data, ctx)
-        self.id = "Event"
-        self.name = name
-        self.data = data
-        if self.data is None:
-            self.data = {}
-        self.ctx = ctx  # CtxItem
-        self.stop = False  # True to stop propagation
-        self.internal = False
-        # internal event, not called from user
-        # internal event is handled synchronously, ctx item has internal flag
-
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Dump event to dict
-
-        :return: Event dict
-        """
-        return {
-            'name': self.name,
-            'data': self.data,
-            'ctx': self.ctx.to_dict() if self.ctx else None,
-            'stop': self.stop,
-            'internal': self.internal,
-        }
-
-    def dump(self) -> str:
-        """
-        Dump event to json string
-
-        :return: JSON string
-        """
-        try:
-            return json.dumps(self.to_dict())
-        except Exception as e:
-            pass
-        return ""
-
-    def __str__(self) -> str:
-        """
-        String representation of event
-
-        :return: Event string
-        """
-        return self.dump()
\ No newline at end of file
+    USER_SEND = "user.send"
\ No newline at end of file
