@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.21 21:00:00                  #
+# Updated Date: 2025.08.02 20:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict
@@ -67,6 +67,15 @@ class LLM:
         """
         return self.llms[id].name if id in self.llms else id
 
+    def get(self, id: str):
+        """
+        Get LLM provider by id
+
+        :param id: LLM id
+        :return: LLM provider instance
+        """
+        return self.llms[id] if id in self.llms else None
+
     def register(
             self,
             id: str,
