@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.05 18:00:00                  #
+# Updated Date: 2025.09.14 20:00:00                  #
 # ================================================== #
 
 from datetime import datetime
@@ -140,6 +140,19 @@ class Tab:
                 ref.deleteLater()
         del self.refs[:]
 
+    def delete_ref(self, widget: Any) -> None:
+        """
+        Unpin reference to widget in this tab
+
+        :param widget: widget reference
+        """
+        for ref in self.refs:
+            if ref and ref is widget:
+                self.refs.remove(ref)
+                break
+        if self.child and hasattr(self.child, 'delete_ref'):
+            self.child.delete_ref(widget)
+
     def to_dict(self) -> Dict[str, Any]:
         """
         Convert to dict
