@@ -6,15 +6,32 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.06 19:00:00                  #
+# Updated Date: 2025.09.05 18:00:00                  #
 # ================================================== #
 
 import datetime
 import json
 import time
+from dataclasses import dataclass
+from typing import Optional
 
 
+@dataclass(slots=True)
 class CalendarNoteItem:
+    id: int = 0
+    uuid: Optional[object] = None
+    idx: int = 0
+    year: int = 0
+    month: int = 0
+    day: int = 0
+    status: int = 0
+    title: str = ""
+    content: str = ""
+    deleted: bool = False
+    created: int = 0
+    updated: int = 0
+    important: bool = False
+    initialized: bool = False
 
     def __init__(self):
         self.id = 0
@@ -74,4 +91,4 @@ class CalendarNoteItem:
 
     def __str__(self):
         """To string"""
-        return self.dump()
+        return self.dump()
\ No newline at end of file
