@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.24 23:00:00                  #
+# Updated Date: 2025.09.12 23:47:47                  #
 # ================================================== #
 
 import datetime
@@ -47,12 +47,26 @@ class ContextList(BaseList):
             'attachment': QIcon(":/icons/attachment.svg"),
         }
         self._color_icon_cache = {}
+
+        # Use a custom delegate for labels/pinned/attachment indicators and group border indicator
         self.setItemDelegate(ImportantItemDelegate(self, self._icons['attachment']))
+
+        # Ensure context menu works as before
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         self.customContextMenuRequested.connect(self.show_context_menu)
         self._backup_selection = None
         self.restore_after_ctx_menu = True
 
+        # Make group rows visually stick to the left edge (if this is a tree view).
+        # Children remain indented by delegate's manual shift (+15 px), preserving structure.
+        try:
+            if hasattr(self, 'setIndentation'):
+                # Set tree indentation to 0 so group/folder rows do not look like children
+                self.setIndentation(0)
+        except Exception:
+            # Safe no-op if the underlying view does not support setIndentation
+            pass
+
     @property
     def _model(self):
         return self.window.ui.models['ctx.list']
@@ -62,6 +76,9 @@ class ContextList(BaseList):
         return self.window.ui.nodes['ctx.list']
 
     def _color_icon(self, color: QColor) -> QIcon:
+        """
+        Returns (and caches) a solid color icon pixmap for menu items.
+        """
         key = color.rgba()
         icon = self._color_icon_cache.get(key)
         if icon is None:
@@ -405,11 +422,19 @@ class ContextList(BaseList):
 
 class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
     """
-    Label color delegate
+    Item delegate that paints:
+    - Attachment icon on the right side (centered vertically),
+    - Pinned indicator (small circle) in the top-right corner (overlays if needed),
+    - Label color as a full-height vertical bar on the left for labeled items,
+    - Group enclosure indicator for expanded groups:
+        - thin vertical bar (default 2 px) on the left side of child rows area,
+        - thin horizontal bar (default 2 px) at the bottom of the last child row.
     """
     def __init__(self, parent=None, attachment_icon: QIcon = None):
         super().__init__(parent)
         self._attachment_icon = attachment_icon or QIcon(":/icons/attachment.svg")
+
+        # Predefined label colors (status -> QColor)
         self._status_colors = {
             0: QColor(100, 100, 100),
             1: QColor(255, 0, 0),
@@ -420,64 +445,219 @@ class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
             6: QColor(75, 0, 130),
             7: QColor(238, 130, 238),
         }
+
+        # Visual tuning constants
         self._pin_pen = QtGui.QPen(QtCore.Qt.black, 0.5, QtCore.Qt.SolidLine)
+        self._pin_diameter = 4            # Small pinned circle diameter
+        self._pin_margin = 3              # Margin from top and right edges
+        self._attach_spacing = 4          # Kept for potential future layout tweaks
+        self._label_bar_width = 4         # Full-height label bar width (left side)
+        self._label_v_margin = 3          # 3px top/bottom margin for the label bar
+
+        # Manual child indent to keep hierarchy visible when view indentation is 0
+        self._child_indent = 15
+
+        # Group indicator defaults (can be overridden by config)
+        self._group_indicator_enabled = True
+        self._group_indicator_width = 2
+        self._group_indicator_color = QColor(67, 75, 78)  # soft gray
+        self._group_indicator_gap = 6  # gap between child content left and the vertical bar
+        self._group_indicator_bottom_offset = 6
+
+        # Try to load customization from application config (safe if missing)
+        self._init_group_indicator_from_config()
+
+    def _init_group_indicator_from_config(self):
+        """
+        Initialize group indicator settings from config if available.
+        Accepts:
+          - color: list/tuple [r,g,b], dict {'r','g','b'}, "#RRGGBB", or "r,g,b"
+          - width: int
+          - enabled: bool
+          - gap: int
+        """
+        try:
+            view = self.parent()
+            window = getattr(view, 'window', None)
+            cfg = getattr(getattr(window, 'core', None), 'config', None)
+            if not cfg:
+                return
+
+            enabled = cfg.get('ctx.records.groups.indicator.enabled')
+            if enabled is not None:
+                self._group_indicator_enabled = bool(enabled)
+
+            width = cfg.get('ctx.records.groups.indicator.width')
+            if isinstance(width, int) and width >= 0:
+                self._group_indicator_width = int(width)
+
+            gap = cfg.get('ctx.records.groups.indicator.gap')
+            if isinstance(gap, int) and gap >= 0:
+                self._group_indicator_gap = int(gap)
+
+            color = cfg.get('ctx.records.groups.indicator.color')
+            qcolor = self._parse_qcolor(color)
+            if qcolor is not None:
+                self._group_indicator_color = qcolor
+        except Exception:
+            # Fail-safe: keep defaults if anything goes wrong
+            pass
+
+    def _parse_qcolor(self, value):
+        """
+        Parses various color formats into QColor.
+        Supports:
+          - QColor
+          - list/tuple [r, g, b]
+          - dict {'r':..,'g':..,'b':..} or {'red':..,'green':..,'blue':..}
+          - "#RRGGBB"
+          - "r,g,b" (also "r;g;b")
+        """
+        if value is None:
+            return None
+        if isinstance(value, QColor):
+            return value
+        if isinstance(value, (list, tuple)) and len(value) >= 3:
+            try:
+                r, g, b = int(value[0]), int(value[1]), int(value[2])
+                return QColor(r, g, b)
+            except Exception:
+                return None
+        if isinstance(value, dict):
+            keys = value.keys()
+            try:
+                if all(k in keys for k in ('r', 'g', 'b')):
+                    return QColor(int(value['r']), int(value['g']), int(value['b']))
+                if all(k in keys for k in ('red', 'green', 'blue')):
+                    return QColor(int(value['red']), int(value['green']), int(value['blue']))
+            except Exception:
+                return None
+        if isinstance(value, str):
+            s = value.strip()
+            if s.startswith('#'):
+                qc = QColor(s)
+                return qc if qc.isValid() else None
+            s = s.replace(';', ',')
+            parts = [p.strip() for p in s.split(',') if p.strip()]
+            if len(parts) >= 3:
+                try:
+                    r, g, b = int(parts[0]), int(parts[1]), int(parts[2])
+                    return QColor(r, g, b)
+                except Exception:
+                    return None
+        return None
 
     def paint(self, painter, option, index):
-        if index.parent().isValid():
-            option.rect.adjust(15, 0, 0, 0)
+        # Shift children by +15 px to keep them visually nested.
+        is_child = index.parent().isValid()
+        if is_child:
+            option.rect.adjust(self._child_indent, 0, 0, 0)
 
-        super(ImportantItemDelegate, self).paint(painter, option, index)
-
-        data = index.data(QtCore.Qt.ItemDataRole.UserRole)
-        if data:
-            label = data.get("label", 0)
-            is_important = data.get("is_important", False)
-            is_attachment = data.get("is_attachment", False)
+        # Detect if this row is a group/folder (top-level section).
+        is_group = False
+        try:
+            model = index.model()
+            item = model.itemFromIndex(index) if hasattr(model, "itemFromIndex") else None
+            is_group = bool(item is not None and getattr(item, 'isFolder', False))
+        except Exception:
+            is_group = False
 
+        # Default painting:
+        # - For groups: translate painter -8 px to push folder/icon closer to the left edge.
+        # - For others: paint normally.
+        if is_group:
             painter.save()
-
-            if is_attachment:
-                icon_size = option.decorationSize or QtCore.QSize(16, 16)
-                icon_pos = option.rect.right() - icon_size.width()
-                y = option.rect.top() + (option.rect.height() - icon_size.height()) // 2
-                icon_rect = QtCore.QRect(
-                    icon_pos,
-                    y,
-                    icon_size.width(),
-                    icon_size.height()
-                )
-                self._attachment_icon.paint(painter, icon_rect, QtCore.Qt.AlignCenter)
-
-            if is_important:
-                color = self.get_color_for_status(3)
-                square_size = 3
-                square_rect = QtCore.QRect(
-                    option.rect.left(),
-                    option.rect.top() + 2,
-                    square_size,
-                    square_size,
-                )
-                painter.setBrush(color)
-                painter.setPen(self._pin_pen)
-                painter.drawRect(square_rect)
-
-            if label > 0:
-                color = self.get_color_for_status(label)
-                square_size = 5
-                y = option.rect.center().y() - (square_size // 2) + 2
-                square_rect = QtCore.QRect(
-                    option.rect.left(),
-                    y,
-                    square_size,
-                    square_size,
-                )
-                painter.setBrush(color)
-                painter.setPen(QtCore.Qt.NoPen)
-                painter.drawRect(square_rect)
-
+            painter.translate(-2, 0)
+            super(ImportantItemDelegate, self).paint(painter, option, index)
             painter.restore()
+        else:
+            super(ImportantItemDelegate, self).paint(painter, option, index)
+
+        # Group enclosure indicator (left bar + bottom bar on last child)
+        # This applies only to child rows (i.e., when a group is expanded).
+        if self._group_indicator_enabled and not is_group and is_child and self._group_indicator_width > 0:
+            try:
+                painter.save()
+                # Use solid fill for crisp 2px bars (no anti-alias blur)
+                painter.setRenderHint(QtGui.QPainter.Antialiasing, False)
+                color = self._group_indicator_color
+                painter.setPen(QtCore.Qt.NoPen)
+                painter.setBrush(color)
+
+                # Compute vertical bar geometry:
+                # Place the bar to the LEFT of the child content area, leaving a small gap.
+                child_left = option.rect.x()
+                bar_w = self._group_indicator_width
+                # Left edge of the vertical bar (never below 0)
+                vbar_left = max(0, child_left - (self._group_indicator_gap + bar_w))
+                vbar_rect = QtCore.QRect(vbar_left, option.rect.y(), bar_w, option.rect.height())
+                painter.drawRect(vbar_rect)
+
+                painter.restore()
+            except Exception:
+                # Fail-safe: do not block painting if anything goes wrong
+                pass
+
+        # Custom data painting for non-group items only (labels, pinned, attachments).
+        if not is_group:
+            data = index.data(QtCore.Qt.ItemDataRole.UserRole)
+            if data:
+                label = data.get("label", 0)
+                is_important = data.get("is_important", False)
+                is_attachment = data.get("is_attachment", False)
+
+                painter.save()
+
+                # Draw attachment icon on the right (centered vertically).
+                # This is painted first, so the pin can overlay it when needed.
+                icon_size = option.decorationSize or QtCore.QSize(16, 16)
+                if is_attachment:
+                    icon_pos_x = option.rect.right() - icon_size.width()
+                    icon_pos_y = option.rect.top() + (option.rect.height() - icon_size.height()) // 2
+                    icon_rect = QtCore.QRect(
+                        icon_pos_x,
+                        icon_pos_y,
+                        icon_size.width(),
+                        icon_size.height()
+                    )
+                    self._attachment_icon.paint(painter, icon_rect, QtCore.Qt.AlignCenter)
+
+                # Pinned indicator (small circle) kept at a fixed top-right position.
+                # It does not shift left when the attachment is present; it overlays above it.
+                if is_important:
+                    painter.setRenderHint(QtGui.QPainter.Antialiasing, True)
+                    painter.setCompositionMode(QtGui.QPainter.CompositionMode_SourceOver)
+                    color = self.get_color_for_status(3)
+
+                    x = option.rect.x() + option.rect.width() - self._pin_margin - self._pin_diameter
+                    y = option.rect.y() + self._pin_margin
+                    pin_rect = QtCore.QRect(x, y, self._pin_diameter, self._pin_diameter)
+
+                    painter.setBrush(color)
+                    painter.setPen(self._pin_pen)
+                    painter.drawEllipse(pin_rect)
+
+                # Label bar on the left with 3px vertical margins
+                if label > 0:
+                    color = self.get_color_for_status(label)
+                    bar_y = option.rect.y() + self._label_v_margin
+                    bar_h = max(1, option.rect.height() - 2 * self._label_v_margin)
+                    bar_rect = QtCore.QRect(
+                        option.rect.x(),
+                        bar_y,
+                        self._label_bar_width,
+                        bar_h,
+                    )
+                    painter.setBrush(color)
+                    painter.setPen(QtCore.Qt.NoPen)
+                    painter.drawRect(bar_rect)
+
+                painter.restore()
 
     def get_color_for_status(self, status: int) -> QColor:
+        """
+        Returns color mapped for given status value.
+        """
         return self._status_colors.get(status, self._status_colors[0])
 
 
@@ -485,6 +665,7 @@ class GroupItem(QStandardItem):
     def __init__(self, icon, name, id):
         super().__init__(icon, name)
         self.id = id
+        # Keep name as provided; display text is handled by the model/view
         self.name = name
         self.isFolder = True
         self.isPinned = False
@@ -496,6 +677,7 @@ class Item(QStandardItem):
     def __init__(self, name, id):
         super().__init__(name)
         self.id = id
+        # Keep name as provided; display text is handled by the model/view
         self.name = name
         self.isFolder = False
         self.isPinned = False
