@@ -14,6 +14,7 @@ import os
 import re
 from datetime import datetime
 from contextlib import contextmanager
+from typing import Any
 
 from PySide6 import QtCore, QtGui
 from PySide6.QtWidgets import QApplication
@@ -61,6 +62,22 @@ def trans(key: str, reload: bool = False, domain: str = None) -> str:
         locale.reload(domain)
     return locale.get(key, domain)
 
+def sizeof_fmt(num: Any, suffix: str = 'B'):
+    """
+    Convert numbers to human-readable unit formats.
+
+    :param num: number to convert
+    :param suffix: suffix to add
+    :return: human-readable format
+    """
+    if not isinstance(num, (int, float)):
+        return '-'
+    for unit in ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z']:
+        if abs(num) < 1024.0:
+            return f"{num:.1f} {unit}{suffix}".replace('.', ',')
+        num /= 1024.0
+    return f"{num:.1f} Yi{suffix}".replace('.', ',')
+
 
 @contextmanager
 def freeze_updates(widget):
@@ -268,29 +285,27 @@ def natsort(l: list) -> list:
     alphanum_key = lambda key: [convert(c) for c in re.split('([0-9]+)', key)]
     return sorted(l, key=alphanum_key)
 
-def mem_clean():
-    """
-    Clean memory by removing unused variables
-    """
-    return  # temporary disabled
-
+def mem_clean(force: bool = False) -> bool:
+    """Clean memory by removing unused objects"""
+    if not force:
+        return False
     import sys, gc
     ok = False
     try:
         gc.collect()
-    except Exception:
-        pass
+    except Exception as e:
+        print(e)
         
     try:
         QApplication.sendPostedEvents(None, QtCore.QEvent.DeferredDelete)
         QApplication.processEvents(QtCore.QEventLoop.AllEvents, 50)
-    except Exception:
-        pass
+    except Exception as e:
+        print(e)
 
     try:
         QtGui.QPixmapCache.clear()
-    except Exception:
-        pass
+    except Exception as e:
+        print(e)
     
     try:
         if sys.platform.startswith("linux"):
@@ -299,6 +314,7 @@ def mem_clean():
             if hasattr(libc, "malloc_trim"):
                 libc.malloc_trim(0)
                 ok = True
+        '''
         elif sys.platform == "win32":
             import ctypes, ctypes.wintypes
             kernel32 = ctypes.WinDLL("kernel32", use_last_error=True)
@@ -322,6 +338,7 @@ def mem_clean():
                     ok = True
             except Exception:
                 pass
-    except Exception:
-        pass
+        '''
+    except Exception as e:
+        print(e)
     return ok
\ No newline at end of file
